/* 
 * GTKSEISVIEWGL - Library for rendering of 2D seismic data
 *
 * Copyright (C) 2006, 2007 Vladimir Bashkardin
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more av.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Author:  Vladimir Bashkardin  <vovizmus@users.sourceforge.net>
 */

#ifndef __G_SEIS_PALETTE_H__
#define __G_SEIS_PALETTE_H__

#include <glib.h>
#include <glib-object.h>
#include <gdk/gdk.h>

G_BEGIN_DECLS

#define G_SEIS_TYPE_PALETTE            (g_seis_palette_get_type ())
#define G_SEIS_PALETTE(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), G_SEIS_TYPE_PALETTE, GSeisPalette))
#define G_SEIS_PALETTE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), G_SEIS_TYPE_PALETTE, GSeisPaletteClass))
#define G_SEIS_IS_PALETTE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), G_SEIS_TYPE_PALETTE))
#define G_SEIS_IS_PALETTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), G_SEIS_TYPE_PALETTE))
#define G_SEIS_GET_PALETTE_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), G_SEIS_TYPE_PALETTE, GSeisPaletteClass))

#define G_TYPE_SEIS_COLOR              (g_seis_color_get_type ())

typedef struct _GSeisColor GSeisColor;

struct _GSeisColor {
    guint16 red;
    guint16 green;
    guint16 blue;
};

GSeisColor *g_seis_color_copy (const GSeisColor *color);
void g_seis_color_free (GSeisColor *color);
GType g_seis_color_get_type (void) G_GNUC_CONST;

typedef struct _GSeisPalette GSeisPalette;
typedef struct _GSeisPaletteClass GSeisPaletteClass;

struct _GSeisPalette {
    GObject parent;
};

struct _GSeisPaletteClass {
    GObjectClass parent_class;
};

typedef struct _GSeisPaletteDef GSeisPaletteDef;

struct _GSeisPaletteDef {
    GSeisColor color_start;
    GSeisColor color_end;
    gfloat     scale_position;   // Relative location on the scale [0; 1]
    gboolean   interpolate;      // TRUE - linearly interpolate to the next color
    gboolean   overlap_next_def; // TRUE - use start color of the next def instead of own end color
};

GType g_seis_palette_get_type (void);

const gchar* g_seis_palette_get_name (GSeisPalette *self);
GSeisPalette* g_seis_palette_new_by_min_max (GSeisColor *min_color, GSeisColor *max_color,
                                             const gchar *name);
GSeisPalette* g_seis_palette_new_by_array (GArray *seis_palette_def, const gchar *name);

GdkPixbuf* g_seis_palette_get_color_scale (GSeisPalette *self);

void g_seis_palette_apply_pixel_map_lookup_tables (GSeisPalette *self, gboolean inverse);
void g_seis_palette_apply_shared_palette_lookup_tables (GSeisPalette *self, gpointer palette_ext,
                                                        gboolean inverse);
void g_seis_palette_generate_fragment_shader_palette_lookup_tables (GSeisPalette *self, guint color_table_size,
                                                                    guint tex_pal_id, gboolean inverse);
void g_seis_palette_apply_fragment_shader_palette_lookup_tables (GSeisPalette *self, guint color_table_size,
                                                                 guint tex_pal_id, gboolean inverse);

GPtrArray *g_seis_view_get_predefined_palettes (void);

guint g_seis_view_get_color_table_sizes (guint **color_table_sizes);

G_END_DECLS
#endif /* __G_SEIS_PALETTE_H__ */
