/* 
 * GTKSEISVIEWGL - Library for rendering of 2D seismic data
 *
 * Copyright (C) 2006 Vladimir Bashkardin
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more av.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Author:  Vladimir Bashkardin  <vovizmus@users.sourceforge.net>
 */

#ifndef __G_SEIS_VIEW_AXIS_H__
#define __G_SEIS_VIEW_AXIS_H__

#include <gtk/gtk.h>
#include <gtkseisviewgl/gseisviewdatavis.h>

G_BEGIN_DECLS

#define G_SEIS_TYPE_VIEW_AXIS            (g_seis_view_axis_get_type ())
#define G_SEIS_VIEW_AXIS(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), G_SEIS_TYPE_VIEW_AXIS, GSeisViewAxis))
#define G_SEIS_VIEW_AXIS_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), G_SEIS_TYPE_VIEW_AXIS, GSeisViewAxisClass))
#define G_SEIS_IS_VIEW_AXIS(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), G_SEIS_TYPE_VIEW_AXIS))
#define G_SEIS_IS_VIEW_AXIS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), G_SEIS_TYPE_VIEW_AXIS))
#define G_SEIS_VIEW_AXIS_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), G_SEIS_TYPE_VIEW_AXIS, GSeisViewAxisClass))

typedef struct _GSeisViewAxis GSeisViewAxis;
typedef struct _GSeisViewAxisClass GSeisViewAxisClass;

typedef enum {
    G_SEIS_VIEW_AXIS_TOP,
    G_SEIS_VIEW_AXIS_BOTTOM,
    G_SEIS_VIEW_AXIS_LEFT,
    G_SEIS_VIEW_AXIS_RIGHT,
    G_SEIS_VIEW_AXES_TYPES_NUM,
} GSeisViewAxisType;

struct _GSeisViewAxis {
    GObject parent;

    GSeisViewAxisType type;

    guint16 size_pixels;
};

struct _GSeisViewAxisClass {
    GObjectClass parent_class;

	void (*view_attach_notify) (GSeisViewAxis *self, GtkWidget *seis_view_gl,
                                GSeisViewDataVisibility *data_visibility);
	void (*view_detach_notify) (GSeisViewAxis *self, GtkWidget *seis_view_gl,
                                GSeisViewDataVisibility *data_visibility);

	void (*view_data_viewport_change) (GSeisViewAxis *self, GtkWidget *seis_view_gl,
                                       GSeisViewDataVisibility *data_visibility);

	void (*view_redraw_event) (GSeisViewAxis *self, GtkWidget *seis_view_gl,
                               GSeisViewDataVisibility *data_visibility);
	void (*view_resize_event) (GSeisViewAxis *self, GtkWidget *seis_view_gl,
                               GSeisViewDataVisibility *data_visibility);
    void (*axis_reshape) (GSeisViewAxis *axis, GtkWidget *seis_view_gl);
};

GType g_seis_view_axis_get_type (void);

void g_seis_view_axis_attach_notify (GSeisViewAxis *axis, GtkWidget *seis_view_gl,
                                     GSeisViewDataVisibility *data_visibility);
void g_seis_view_axis_detach_notify (GSeisViewAxis *axis, GtkWidget *seis_view_gl,
                                     GSeisViewDataVisibility *data_visibility);
void g_seis_view_axis_data_viewport_change (GSeisViewAxis *axis, GtkWidget *seis_view_gl,
                                            GSeisViewDataVisibility *data_visibility);
void g_seis_view_axis_redraw_event (GSeisViewAxis *axis, GtkWidget *seis_view_gl,
                                    GSeisViewDataVisibility *data_visibility);
void g_seis_view_axis_resize_event (GSeisViewAxis *axis, GtkWidget *seis_view_gl,
                                    GSeisViewDataVisibility *data_visibility);

void g_seis_view_axis_reshape (GSeisViewAxis *axis, GtkWidget *seis_view_gl);

G_END_DECLS

#endif /* __G_SEIS_VIEW_AXIS_H__ */
