/* 
 * GTKSEISVIEWGL - Library for rendering of 2D seismic data
 *
 * Copyright (C) 2006 Vladimir Bashkardin
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more av.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 *
 * Author:  Vladimir Bashkardin  <vovizmus@users.sourceforge.net>
 */

#ifndef __G_SEIS_VIEW_LIGHT_BUMP_H__
#define __G_SEIS_VIEW_LIGHT_BUMP_H__

#include <gtkseisviewgl/gtklightdirection.h>
#include <gtkseisviewgl/gseispalette.h>
#include <gtkseisviewgl/gseisviewlight.h>

G_BEGIN_DECLS

#define G_SEIS_TYPE_VIEW_LIGHT_BUMP            (g_seis_view_light_bump_get_type ())
#define G_SEIS_VIEW_LIGHT_BUMP(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), G_SEIS_TYPE_VIEW_LIGHT_BUMP, GSeisViewLightBump))
#define G_SEIS_VIEW_LIGHT_BUMP_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), G_SEIS_TYPE_VIEW_LIGHT_BUMP, GSeisViewLightBumpClass))
#define G_SEIS_IS_VIEW_LIGHT_BUMP(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), G_SEIS_TYPE_VIEW_LIGHT_BUMP))
#define G_SEIS_IS_VIEW_LIGHT_BUMP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), G_SEIS_TYPE_VIEW_LIGHT_BUMP))
#define G_SEIS_VIEW_LIGHT_BUMP_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), G_SEIS_TYPE_VIEW_LIGHT_BUMP, GSeisViewLightBumpClass))

typedef struct _GSeisViewLightBump GSeisViewLightBump;
typedef struct _GSeisViewLightBumpClass GSeisViewLightBumpClass;

struct _GSeisViewLightBump {
    GSeisViewLight parent;
};

struct _GSeisViewLightBumpClass {
    GSeisViewLightClass parent_class;

    guint lights_ready_id;

    void (*lights_ready) (GSeisViewLightBump *self);
};

GType g_seis_view_light_bump_get_type (void);

GSeisViewLightBump* g_seis_view_light_bump_new (void);

guint g_seis_view_light_bump_get_max_lights (GSeisViewLightBump *self);
guint g_seis_view_light_bump_get_num_lights (GSeisViewLightBump *self);
guint g_seis_view_light_bump_get_active_light (GSeisViewLightBump *self);
void g_seis_view_light_bump_get_diffuse_light_color (GSeisViewLightBump *self, GSeisColor *color);
gfloat g_seis_view_light_bump_get_diffuse_light_factor (GSeisViewLightBump *self);

void g_seis_view_light_bump_set_num_lights (GSeisViewLightBump *self, guint num_lights);
void g_seis_view_light_bump_set_active_light (GSeisViewLightBump *self, guint active_light);
void g_seis_view_light_bump_set_diffuse_light_color (GSeisViewLightBump *self, const GSeisColor *color);
void g_seis_view_light_bump_set_diffuse_light_factor (GSeisViewLightBump *self, gfloat factor);

void g_seis_view_light_bump_get_ambient_light_color (GSeisViewLightBump *self, GSeisColor *color);
gfloat g_seis_view_light_bump_get_ambient_light_factor (GSeisViewLightBump *self);
gfloat g_seis_view_light_bump_get_emission_factor (GSeisViewLightBump *self);

void g_seis_view_light_bump_set_ambient_light_color (GSeisViewLightBump *self, const GSeisColor *color);
void g_seis_view_light_bump_set_ambient_light_factor (GSeisViewLightBump *self, gfloat factor);
void g_seis_view_light_bump_set_emission_factor (GSeisViewLightBump *self, gfloat factor);

void g_seis_view_light_bump_set_diffuse_light_position (GSeisViewLightBump *self, const GtkLightPosition *position);

G_END_DECLS

#endif /* __G_SEIS_VIEW_LIGHT_BUMP_H__ */
